import { queryOne } from '../../services/merchant';
import pathToRegexp from 'path-to-regexp';

export default {
  namespace: 'merchantDetail',

  state: {
    filters: {},
    currentItem: {},
    itemLoading: false,
  },

  subscriptions: {
    setup({ dispatch, history }) {
      history.listen(({ pathname, state }) => {
        const match = pathToRegexp('/merchant/edit/:id').exec(pathname);
        if (match) {
          dispatch({ type: 'query', payload: { id: match[1] } });
          dispatch({ type: 'saveFilters', payload: state });
        }
      });
    }
  },

  effects: {
    * query ({ payload }, { call, put }) {
      yield put({ type: 'changeLoading', payload: { itemLoading: true } });
      const { data, success } = yield call(queryOne, payload);
      if (success) {
        yield put({ type: 'querySuccess', payload: { ...data } });
      }
      yield put({ type: 'changeLoading', payload: { itemLoading: false } });
    }
  },

  reducers: {
    changeLoading(state, { payload }) {
      return { ...state, ...payload };
    },

    querySuccess(state, { payload }) {
      return { ...state, currentItem: payload };
    },

    saveFilters(state, { payload: filters }) {
      return { ...state, filters };
    },
  }
}
