import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
// import { InputNumber } from 'antd';
import SelectModal from '../../../components/SelectModal';
import { Codes } from '../../../utils/config';

export default class ProductSelectModal extends PureComponent {

  render() {
    const {
      rowKeyName,
      selTableData,
      modalVisible,
      onCancel,
      onOk,
      onSearch,
      ...fsTableOpts
    } = this.props;

    const modalProps = {
      title: '选择产品',
      maskClosable: false,
      visible: modalVisible,
      onCancel,
      onOk,
    };

    const searchProps = {
      searchField: 'name',
      searchKeyWord: '',
      searchSize: 'default',
      searchSelect: true,
      searchSelectOptions: [{
        value: 'name', name: '产品名称', mode: 'input',
      },{
        value: 'code', name: '产品编号', mode: 'input',
      }],
      searchSelectProps: {
        defaultValue: 'name',
      },
      onSearch: (value) => {
        onSearch(value);
      },
    };

    //已选资源列表
    const selTableProps = {
      operDel: true,
      tablePagination: false,
      tableDataSource: selTableData,
      rowKeyName: rowKeyName,
      tableColumns: [{
        title: '封面图片',
        dataIndex: 'coverUrl',
        key: 'coverUrl',
        width: '22%'
      },{
        title: '产品编号',
        dataIndex: 'code',
        key: 'code',
        width: '22%',
      },{
        title: '产品名称',
        dataIndex: 'name',
        key: 'name',
        width: '22%',
      },{
        title: '供应商',
        dataIndex: 'cpName',
        key: 'cpName',
        width: '22%',
      // },{
      //   title: '定价',
      //   dataIndex: 'cpPrice',
      //   key: 'cpPrice',
      //   width: '16%',
      //   render: (text, record) => (
      //     <InputNumber
      //       min={0}
      //       value={record.cpPrice}
      //       onChange={(value) => {record.cpPrice = value}}
      //       formatter={value => `¥ ${value}`.replace(/\B(?=(\d{3})+(?!\d))/g, ',')}
      //       parser={value => value.replace(/\¥\s?|(,*)/g, '')}
      //     />
      //   ),
      }]
    };

    //待选资源Table属性
    const fsTableProps = {
      fsTableColumns: [{
        title: '封面图片',
        dataIndex: 'coverUrl',
        key: 'coverUrl',
        width: '22%'
      },{
        title: '产品编号',
        dataIndex: 'code',
        key: 'code',
        width: '22%%',
      },{
        title: '产品名称',
        dataIndex: 'name',
        key: 'name',
        width: '22%',
      },{
        title: '供应商',
        dataIndex: 'cpName',
        key: 'cpName',
        width: '22%',
      }],
      ...fsTableOpts,
    }

    return (
      <SelectModal
        mode="multiple"
        { ...searchProps }
        { ...selTableProps }
        { ...fsTableProps }
        { ...modalProps }
      />
    );
  }
}
