import React, { PureComponent } from 'react';
import { routerRedux } from 'dva/router';
import PropTypes from 'prop-types';
import queryString from 'query-string';
import { connect } from 'dva';
import { Spin, Card, Form } from 'antd';
import PageHeaderLayout from '../../../layouts/PageHeaderLayout';
import BaseInfoCard from './baseInfo';
import RecommendList from './recommend';

@connect(state => ({ merchantDetail: state.merchantDetail }))
export default class MerchantDetail extends PureComponent {
  static propTypes = {
    merchantDetail: PropTypes.object,
  };

  state = { curTab: 'baseInfo' };

  handleTabChange = (key) => {
    this.setState({ curTab: key });
  }

  render() {
    const { dispatch, merchantDetail } = this.props;
    const { itemLoading, currentItem, filters } = merchantDetail;

    const tabList = [{
      key: 'baseInfo',
      tab: '基础信息',
    },{
      key: 'recommend',
      tab: '推荐位设置',
    }];

    const baseInfoCardProps = {
      item: currentItem,
      onCancel: () => {
        dispatch(
          routerRedux.push({
            pathname: '/merchant',
            search: queryString.stringify(filters)
          })
        );
      },
      onSubmit: (data) => {
        console.log(data);
      }
    };
    const recommendCardProps = {

    };

    const contentMap = {
      baseInfo: <BaseInfoCard { ...baseInfoCardProps }/>,
      recommend: <RecommendList />
    };

    return (
      <PageHeaderLayout
        title="相关配置"
        tabList={tabList}
        onTabChange={this.handleTabChange}
      >
        <Spin spinning={itemLoading}>
          {contentMap[this.state.curTab]}
        </Spin>
      </PageHeaderLayout>
    );
  }
}
