import React, { Component } from 'react';
import { connect } from 'dva';
import { Card, Badge, Table, Divider } from 'antd';
import moment from 'moment';
import PageHeaderLayout from '../../../layouts/PageHeaderLayout';
import DescriptionList from '../../../components/DescriptionList';
import { Codes, orderStatuses } from '../../../utils/config';
import styles from './orderProfile.less';

const { Description } = DescriptionList;

@connect(state => ({ orderDetail: state.orderDetail }))
export default class OrderProfile extends Component {
  render() {
    const { orderDetail } = this.props;
    const { currentItem } = orderDetail;
    const { code, gmtCreated, userCode, status, provinceCode, cityName, zoneName, classroomName } = currentItem;

    const goodsTableColumns = [{
      title: '商品编号',
      dataIndex: 'code',
      key: 'code',
    },{
      title: '商品类型',
      dataIndex: 'type',
      key: 'type',
    },{
      title: '商品名称',
      dataIndex: 'name',
      key: 'name',
    },{
      title: '领教定价',
      dataIndex: 'lingjiaoPrice',
      key: 'lingjiaoPrice',
    },{
      title: '渠道定价',
      dataIndex: 'merchantPrice',
      key: 'merchantPrice',
    },{
      title: '实际售价',
      dataIndex: 'finalPrice',
      key: 'finalPrice',
    },{
      title: '数量',
      dataIndex: 'quality',
      key: 'quality',
    },{
      title: '单位',
      dataIndex: 'chargeUnit',
      key: 'chargeUnit',
    },{
      title: '起始时间',
      dataIndex: 'timeBegin',
      key: 'timeBegin',
    },{
      title: '结束时间',
      dataIndex: 'timeEnd',
      key: 'timeEnd',
    }];

    return (
      <PageHeaderLayout title="订单详情">
        <Card bordered={false}>
          <DescriptionList size="large" title="订单信息" col={2} style={{ marginBottom: 32 }}>
            <Description term="订单编号">{code}</Description>
            <Description term="创建时间">{moment(gmtCreated).format('YYYY-MM-DD HH:mm:ss')}</Description>
            <Description term="终端编号">{userCode}</Description>
            <Description term="终端名称">{`${provinceCode}-${cityName}-${zoneName}-${classroomName}`}</Description>
            <Description term="支付状态">{orderStatuses[status]}</Description>
          </DescriptionList>
          <Divider style={{ marginBottom: 32 }} />
          <DescriptionList size="large" title="收货信息" col={2} style={{ marginBottom: 32 }}>
            <Description term="收货人">付小小</Description>
            <Description term="联系电话">18100000000</Description>
            <Description term="收货地址">浙江省杭州市西湖区万塘路18号</Description>
            <Description term="备注">无</Description>
          </DescriptionList>
          <Divider style={{ marginBottom: 32 }} />
          <div className={styles.title}>商品清单</div>
          <Table
            dataSource={[]}
            columns={goodsTableColumns}
          />
        </Card>
      </PageHeaderLayout>
    );
  }
}
