import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import { message, Form, Switch, Input, Modal } from 'antd';
import Uploader from '../../../components/Uploader';
import { Codes, statuses } from '../../../utils/config';

const FormItem = Form.Item;

@Form.create()
export default class ModalForm extends PureComponent {
  static propTypes = {
    item: PropTypes.object,
    form: PropTypes.object,
    onOk: PropTypes.func,
    onCancel: PropTypes.func,
  };

  constructor(props) {
    super(props);
    this.state = { item: props.item };
  }

  componentWillReceiveProps(nextProps) {
    if (nextProps.item) {
      this.setState({ item: { ...nextProps.item } });
    }
  }

  // 图片上传成功
  handleSingleUpload = (file, fileName, signature) => {
    if (file) {
      const separatorIndex = file.name.lastIndexOf('.');
      const name = file.name.substring(0, separatorIndex);
      const suffix = file.name.substring(separatorIndex + 1, file.name.length);
      const data = {
        name,
        format: suffix,
        size: file.size,
        code: name,
        url: `${signature.host}/${signature.dir}${fileName}`,
      };
      message.success('图片上传成功!');
      this.setState({ item: { ...this.state.item, ...data } });
    } else {
      // 图片被移除，重置state为空
      this.setState({ item: {} });
    }
  }

  handleOk = () => {
    const { form: { validateFields, getFieldsValue }, item, onOk } = this.props;
    validateFields((errors) => {
      if (errors) { return; }
      const data = {
        ...getFieldsValue(),
      };
      item.id ? data.id = item.id : null;
      onOk(data);
    });
  }

  handleCancel = () => {
    const { onCancel, form: { resetFields } } = this.props;
    //退出模态框，把state中的item重置为空
    this.setState({ item: {} });
    resetFields();
    onCancel();
  }

  render() {
    const { signature, form: { getFieldDecorator }, ...modalProps } = this.props;
    const { item } = this.state;

    const formItemLayout = {
      labelCol: {
        span: 7,
      },
      wrapperCol: {
        span: 14,
      },
    };

    const modalOpts = {
      ...modalProps,
      onOk: this.handleOk,
      onCancel: this.handleCancel,
    };

    return (
      <Modal key={this.props.item.id} {...modalOpts}>
        <Form layout="horizontal">
          <FormItem label="单图上传" {...formItemLayout}>
            <Uploader
              accept="image"
              files={item.url}
              signature={signature}
              onUpload={::this.handleSingleUpload}
            />
          </FormItem>
          <FormItem label="图片编号：" hasFeedback {...formItemLayout}>
            {getFieldDecorator('code', {
              rules: [{ required: true, type: 'string', message: "此项为必填项!" }],
              initialValue: item.code,
            })(<Input />)}
          </FormItem>
          <FormItem label="图片名称：" hasFeedback {...formItemLayout}>
            {getFieldDecorator('name', {
              rules: [{ required: true, type: 'string', message: "此项为必填项!" }],
              initialValue: item.name,
            })(<Input />)}
          </FormItem>
          <FormItem label="图片格式：" {...formItemLayout}>
            {getFieldDecorator('format', {
              initialValue: item.format,
            })(<Input placeholder="自动生成" />)}
          </FormItem>
          <FormItem label="图片大小：" {...formItemLayout}>
            {getFieldDecorator('size', {
              initialValue: item.size,
            })(<Input placeholder="自动生成" suffix={"字节"} />)}
          </FormItem>
          {/*
          <FormItem label="使用状态：" {...formItemLayout}>
            {getFieldDecorator('status', {
              valuePropsName: 'checked',
          })(<Switch defaultChecked={item.status || Codes.CODE_NORMAL === Codes.CODE_NORMAL ? true : false} checkedChildren="使用中" unCheckedChildren="已删除" />)}
          </FormItem>
          */}
        </Form>
      </Modal>
    );
  }
}
